@@ -2,7 +2,6 @@ package Bio::DOOP::Cluster;
 
 use strict;
 use warnings;
-use Carp qw(cluck carp verbose);
 
 =head1 NAME
 
@@ -10,15 +9,15 @@ use Carp qw(cluck carp verbose);
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
-  This object represents a cluster. You can access properties through the methods.
+  This object represents a cluster. You can access the properties through the methods.
   Usage:
 
   $cluster = Bio::DOOP::Cluster->new($db,"81007400","500");
@@ -36,7 +35,7 @@ sub new {
   my $self                 = {};
   my $dummy                = shift;
   my $db                   = shift;
-     $self->{ID}           = shift;  # This is the cluster_id field in the MySQL tables.
+     $self->{ID}           = shift;  # cluster_id field in the MySQL tables.
      $self->{PROMO_TYPE}   = shift;
 
   my $id   = $self->{ID};
@@ -63,7 +62,7 @@ sub new_by_id {
   my $self                 = {};
   my $dummy                = shift;
   my $db                   = shift;
-     $self->{PRIMARY}      = shift;  # This is the cluster_id field in the MySQL tables.
+     $self->{PRIMARY}      = shift;  # cluster_id field in the MySQL tables.
 
   my $id   = $self->{PRIMARY};
 
@@ -91,6 +90,7 @@ sub new_by_id {
 =head2 new
 
   $cluster = Bio::DOOP::Cluster->new($db,"8010110","500");
+
   Create a new cluster object from the cluster id and promoter type. Every promoter cluster has a uniq
   identifier. This is the cluster id. There are three promoter sizes (500,1000,3000 bp), so the uniq
   cluster is identified by two parameters : cluster id and promoter type.
@@ -101,6 +101,7 @@ sub new_by_id {
 =head2 new_by_id
 
   Bio::DOOP::Cluster->new_by_id($db,"2453");
+
   Used by internal MySQL queries.
   Return type: Bio::DOOP::Cluster object
 
@@ -122,6 +123,8 @@ sub get_id {
 
 =head2 get_cluster_id
 
+  $cluster_id = $cluster->get_cluster_id;
+
   Returns the cluster id.
   Return type: string
 
@@ -204,7 +207,6 @@ sub get_all_subsets {
   my $ret = $self->{DB}->query("SELECT subset_primary_id FROM cluster_subset WHERE cluster_primary_id = $id");
 
   if ($#$ret == -1){
-     #cluck "No subset found!\n";
      return(-1);
   }
 
@@ -220,7 +222,7 @@ sub get_all_subsets {
 
   $subset = $cluster->get_subset_by_type("B");
   if ($subset == -1){
-     print"No subset! Try another type\n";
+     print"No subset! Try another subset type\n";
   }
 
   Returns the subset specified by type.
@@ -236,7 +238,6 @@ sub get_subset_by_type {
   my $ret = $self->{DB}->query("SELECT subset_primary_id FROM cluster_subset WHERE cluster_primary_id = $id AND subset_type = \"$type\"");
 
   if ($#$ret == -1){
-     #cluck "No subset found!\n";
      return(-1);
   }
 
@@ -249,7 +250,7 @@ sub get_subset_by_type {
   @types = @{$cluster->get_available_types};
 
   Returns all available cluster subset types.
-  Return type: arrayref of string.
+  Return type: arrayref of string
 
 =cut
 
@@ -259,7 +260,6 @@ sub get_available_types {
   my $ret = $self->{DB}->query("SELECT subset_type FROM cluster_subset WHERE cluster_primary_id = $id");
 
   if ($#$ret == -1){
-     #cluck "No subset type found!\n";
      return(-1);
   }
 
@@ -286,7 +286,6 @@ sub get_all_seqs {
   my $ret = $self->{DB}->query("SELECT DISTINCT(sequence_primary_id) FROM subset_xref WHERE cluster_primary_id = $id;");
 
   if ($#$ret == -1){
-     #cluck "No sequence found! Something is really fucked up.\n";
      return(-1);
   }
 
@@ -312,7 +311,6 @@ sub get_orig_subset {
   my $id                   = $self->{PRIMARY};
   my $ret = $self->{DB}->query("SELECT subset_primary_id FROM cluster_subset WHERE cluster_primary_id = $id AND original = \"y\"");
   if ($#$ret == -1){
-     #cluck "No original subset!\n";
      return(-1);
   }
   my $subset =  Bio::DOOP::ClusterSubset->new($self->{DB},$$ret[0]->[0]);
@@ -332,11 +330,9 @@ sub get_ref_seq {
   my $self                 = shift;
   my $id                   = $self->{PRIMARY};
 
-  #why taxon_name? taxon_taxid is so much nicer.
   my $ret = $self->{DB}->query("SELECT sequence.sequence_primary_id FROM sequence, taxon_annotation, subset_xref WHERE cluster_primary_id = $id AND (taxon_taxid = '3702' OR taxon_taxid = '9606') AND taxon_annotation.taxon_primary_id = sequence.taxon_primary_id AND sequence.sequence_primary_id = subset_xref.sequence_primary_id;");
   
   if ($#$ret == -1){
-     #cluck "No reference sequence!\n";
      return(-1);
   }
 
