@@ -5,26 +5,26 @@ use warnings;
 
 =head1 NAME
 
-  Bio::DOOP::Util::Sort - sort the array of array objects.
+  Bio::DOOP::Util::Sort - sort an array of arrays.
 
 =head1 VERSION
 
-  Version 0.1
+  Version 0.2
 
 =cut
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 =head1 SYNOPSIS
 
   @result = $mofext->get_results;
   $sorting = Bio::DOOP::Util::Sort->new($db,\results);
-  @sorted_result = $sorting->sort_by_column(1,"asc"); # Sorting ascendent the score
+  @sorted_result = $sorting->sort_by_column(1,"asc"); 
 
 =head1 DESCRIPTION
 
-  This class is sort any type of array of array. It can be used to sort the
-  mofext or fuzznuc results, but can sort any other data.
+  This class can sort any type of array of arrays. It can be used to sort the
+  mofext or fuzznuc results, but can sort other data.
 
 =head1 AUTHORS
 
@@ -34,8 +34,9 @@ our $VERSION = '0.1';
 
 =head2 new
 
-  Create a Sort class.
   $mofext_sort = Bio::DOOP::Util::Sort->new($db,\@mofext_result);
+
+  Create a Sort class.
   Arguments: Bio::DOOP::DBSQL, array of array (practically it is a table)
 
 =cut
@@ -56,8 +57,9 @@ sub new {
 =head2 sort_by_column
 
   @ret = $mofext_sort->sort_by_column(0,"asc");
+
   Sort a given array by column. (Warning, the first column is zero!)
-  Return type: sorted array of array
+  Return type: sorted array of arrays
 
 =cut
 
